% Load data for the pressure system

clear all, close all, clc

Ts = 5;              % sample time [s]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load identification data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DATA(:,1) - time                 DATA(:,2) - output pressure
% DATA(:,3) - measured gas flow    DATA(:,4) - disturbance
% DATA(:,5) - valve position       DATA(:,6) - setpoint for gas flow
% DATA(:,7) - n.a.

load trsart3; Uv = DATA(:,5); Yv = DATA(:,2);
load trsart4; Ut = DATA(:,5); Yt = DATA(:,2);

% Input -> valve position
% Output -> pressure

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load estimation data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load tssart2; Ue = DATA(:,5); Ye = DATA(:,2);
load tssart3; Ue = [Ue;DATA(:,5)]; Ye = [Ye;DATA(:,2)];

N = length(Ue);
tb = [0:Ts:(N-1)*Ts]';

figure
subplot(211), plot(tb,Ue)
title('Process input: % close');
ylabel('Valve position');
xlabel('Time (s)')

subplot(212), plot(tb,Ye)
title('Process output');
ylabel('Pressure');
xlabel('Time (s)')

figure
plot(Ue,Ye,'o')
xlabel('Valve position: % close')
ylabel('Pressure')
title('Pressure vs. valve position')

% Variables for the simulator in Simulink

U = [Ue;Uv;Ut];
Y = [Ye;Yv;Yt];
tfin = (length(U)-1)*Ts;
tsim = [0:Ts:tfin]';

N = length(U);
Nm = round(N/2);
ue = U(1:Nm); uv = U(Nm+1:N);
ye = Y(1:Nm); yv = Y(Nm+1:N);

return